Build an array of Service objects from the response
Returns:
This array will be empty when the response is not a success
24 25 26
# File 'lib/imperium/agent_list_services_response.rb', line 24 def services @services ||= services_hash.values end